# EERILY

timE sERIes pLaYground (EERILY) is a playground for time series.


## Development

Make sure write some tests and check the coverage.

```bash
pytest --cov=. tests/ --cov-report xml:cov.xml
```
